<?php
class Item extends CI_Model
{
	/*
	Determines if a given item_id is an item
	*/
	public function exists($item_id, $ignore_deleted = FALSE, $deleted = FALSE)
	{
		if (ctype_digit($item_id))
		{
			$this->db->from('items');
			$this->db->where('item_id', (int) $item_id);
			if ($ignore_deleted == FALSE)
			{
				$this->db->where('deleted', $deleted);
			}

			return ($this->db->get()->num_rows() == 1);
		}

		return FALSE;
	}

	/*
	Determines if a given item_number exists
	*/
	public function item_number_exists($item_number, $item_id = '')
	{
		$this->db->from('items');
		$this->db->where('item_number', (string) $item_number);
		if(ctype_digit($item_id))
		{
			$this->db->where('item_id !=', (int) $item_id);
		}

		return ($this->db->get()->num_rows() == 1);
	}

	/*
	Gets total of rows
	*/
	public function get_total_rows()
	{
		$this->db->from('items');
		$this->db->where('deleted', 0);

		return $this->db->count_all_results();
	}

	/*
	Get number of rows
	*/
	public function get_found_rows($search, $filters)
	{
		return $this->search($search, $filters)->num_rows();
	}

	/*
	Perform a search on items
	*/
	public function search($search, $filters, $rows = 0, $limit_from = 0, $sort = 'items.name', $order = 'asc')
	{
		$this->db->from('items');
		$this->db->join('suppliers', 'suppliers.person_id = items.supplier_id', 'left');
		$this->db->join('inventory', 'inventory.trans_items = items.item_id');

		if($filters['stock_location_id'] > -1)
		{
			$this->db->join('item_quantities', 'item_quantities.item_id = items.item_id');
			$this->db->where('location_id', $filters['stock_location_id']);
		}

		$this->db->where('DATE_FORMAT(trans_date, "%Y-%m-%d") BETWEEN ' . $this->db->escape($filters['start_date']) . ' AND ' . $this->db->escape($filters['end_date']));

		if(!empty($search))
		{
			if($filters['search_custom'] == FALSE)
			{
				$this->db->group_start();
					$this->db->like('name', $search);
					$this->db->or_like('item_number', $search);
					$this->db->or_like('items.item_id', $search);
					$this->db->or_like('company_name', $search);
					$this->db->or_like('category', $search);
				$this->db->group_end();
			}
			else
			{
				$this->db->group_start();
					$this->db->like('custom1', $search);
					$this->db->or_like('custom2', $search);
					$this->db->or_like('custom3', $search);
					$this->db->or_like('custom4', $search);
					$this->db->or_like('custom5', $search);
					$this->db->or_like('custom6', $search);
					$this->db->or_like('custom7', $search);
					$this->db->or_like('custom8', $search);
					$this->db->or_like('custom9', $search);
					$this->db->or_like('custom10', $search);
				$this->db->group_end();
			}
		}

		$this->db->where('items.deleted', $filters['is_deleted']);

		if($filters['empty_upc'] != FALSE)
		{
			$this->db->where('item_number', NULL);
		}
		if($filters['low_inventory'] != FALSE)
		{
			$this->db->where('quantity <=', 'reorder_level');
		}
		if($filters['is_serialized'] != FALSE)
		{
			$this->db->where('is_serialized', 1);
		}
		if($filters['no_description'] != FALSE)
		{
			$this->db->where('items.description', '');
		}

		// avoid duplicated entries with same name because of inventory reporting multiple changes on the same item in the same date range
		$this->db->group_by('items.item_id');
		
		// order by name of item
		$this->db->order_by($sort, $order);

		if($rows > 0) 
		{	
			$this->db->limit($rows, $limit_from);
		}

		return $this->db->get();
	}
	
	/*
	Returns all the items
	*/
	public function get_all($stock_location_id = -1, $rows = 0, $limit_from = 0)
	{
		$this->db->from('items');
		$this->db->join('suppliers', 'suppliers.person_id = items.supplier_id', 'left');

		if($stock_location_id > -1)
		{
			$this->db->join('item_quantities', 'item_quantities.item_id = items.item_id');
			$this->db->where('location_id', $stock_location_id);
		}

		$this->db->where('items.deleted', 0);

		// order by name of item
		$this->db->order_by('items.name', 'asc');

		if($rows > 0)
		{
			$this->db->limit($rows, $limit_from);
		}

		return $this->db->get();
	}

	/*
	Gets information about a particular item
	*/
	public function get_info($item_id)
	{
		$this->db->select('items.*');
		$this->db->select('suppliers.company_name');
		$this->db->from('items');
		$this->db->join('suppliers', 'suppliers.person_id = items.supplier_id', 'left');
		$this->db->where('item_id', $item_id);

		$query = $this->db->get();

		if($query->num_rows() == 1)
		{
			return $query->row();
		}
		else
		{
			//Get empty base parent object, as $item_id is NOT an item
			$item_obj = new stdClass();

			//Get all the fields from items table
			foreach($this->db->list_fields('items') as $field)
			{
				$item_obj->$field = '';
			}

			return $item_obj;
		}
	}
	
	/*
	Gets information about a particular item by item id or number
	*/
	public function get_info_by_id_or_number($item_id)
	{
		$this->db->from('items');

        if (ctype_digit($item_id))
        {
            $this->db->group_start();

                //$this->db->where('items.item_number', $item_id);
                //Solo debe buscar por codigo de barras o sea item_number
                $this->db->where('item_id', (int) $item_id);
                $this->db->or_where('items.item_number', $item_id);
            $this->db->group_end();
        }
        else
        {
            $this->db->where('item_number', $item_id);
        }

		$this->db->where('items.deleted', 0);

		$query = $this->db->get();

		if($query->num_rows() == 1)
		{
			return $query->row();
		}

		return '';
	}

	/*
	Get an item id given an item number
	*/
	public function get_item_id($item_number, $ignore_deleted = FALSE, $deleted = FALSE)
	{
		$this->db->from('items');
		$this->db->join('suppliers', 'suppliers.person_id = items.supplier_id', 'left');
		$this->db->where('item_number', $item_number);
		if($ignore_deleted == FALSE)
		{
			$this->db->where('items.deleted', $deleted);
		}
        
		$query = $this->db->get();

		if($query->num_rows() == 1)
		{
			return $query->row()->item_id;
		}

		return FALSE;
	}

	/*
	Gets information about multiple items
	*/
	public function get_multiple_info($item_ids, $location_id)
	{
		$this->db->from('items');
		$this->db->join('suppliers', 'suppliers.person_id = items.supplier_id', 'left');
		$this->db->join('item_quantities', 'item_quantities.item_id = items.item_id', 'left');
		$this->db->where('location_id', $location_id);
		$this->db->where_in('items.item_id', $item_ids);

		return $this->db->get();
	}

	/*
	Inserts or updates a item
	*/
	public function save(&$item_data, $item_id = FALSE)
	{
		if(!$item_id || !$this->exists($item_id, TRUE))
		{
			if($this->db->insert('items', $item_data))
			{
				$item_data['item_id'] = $this->db->insert_id();

				return TRUE;
			}

			return FALSE;
		}
		
		$this->db->where('item_id', $item_id);

		return $this->db->update('items', $item_data);
	}

	/*
	Updates multiple items at once
	*/
	public function update_multiple($item_data, $item_ids)
	{
		$this->db->where_in('item_id', explode(':', $item_ids));

		return $this->db->update('items', $item_data);
	}

	/*
	Deletes one item
	*/
	public function delete($item_id)
	{
		//Run these queries as a transaction, we want to make sure we do all or nothing
		$this->db->trans_start();

		// set to 0 quantities
		$this->Item_quantity->reset_quantity($item_id);
		$this->db->where('item_id', $item_id);
		$success = $this->db->update('items', array('deleted'=>1));
		
		$this->db->trans_complete();
		
		$success &= $this->db->trans_status();

		return $success;
	}
	
	/*
	Undeletes one item
	*/
	public function undelete($item_id)
	{
		$this->db->where('item_id', $item_id);

		return $this->db->update('items', array('deleted'=>0));
	}

	/*
	Deletes a list of items
	*/
	public function delete_list($item_ids)
	{
		//Run these queries as a transaction, we want to make sure we do all or nothing
		$this->db->trans_start();

		// set to 0 quantities
		$this->Item_quantity->reset_quantity_list($item_ids);
		$this->db->where_in('item_id', $item_ids);
		$success = $this->db->update('items', array('deleted'=>1));
		
		$this->db->trans_complete();
		
		$success &= $this->db->trans_status();

		return $success;
 	}

	public function get_search_suggestions($search, $filters = array('is_deleted' => FALSE, 'search_custom' => FALSE), $unique = FALSE, $limit = 25)
	{
		$suggestions = array();

		$this->db->select('item_number, name'); //original $this->db->select('item_id, name');
		$this->db->from('items');
		$this->db->where('deleted', $filters['is_deleted']);
		$this->db->where('length(item_number)>0');//Para que solo traiga los que tienen código de barra
		$this->db->like('name', $search);
		$this->db->order_by('name', 'asc');
		foreach($this->db->get()->result() as $row)
		{
			$suggestions[] = array('value' => $row->item_number, 'label' => $row->name);
		}

		//Comentado para que solo busque por codigo de barras o nombre
		$this->db->select('item_id, item_number');
		$this->db->from('items');
		$this->db->where('deleted', $filters['is_deleted']);
		$this->db->like('item_number', $search);
		$this->db->order_by('item_number', 'asc');
		foreach($this->db->get()->result() as $row)
		{
			$suggestions[] = array('value' => $row->item_number, 'label' => $row->item_number); //original $suggestions[] = array('value' => $row->item_id, 'label' => $row->item_number);
		}

		if(!$unique)
		{
			//Search by category
			$this->db->select('category');
			$this->db->from('items');
			$this->db->where('deleted', $filters['is_deleted']);
			$this->db->distinct();
			$this->db->like('category', $search);
			$this->db->order_by('category', 'asc');
			foreach($this->db->get()->result() as $row)
			{
				$suggestions[] = array('label' => $row->category);
			}

			//Search by supplier
			$this->db->select('company_name');
			$this->db->from('suppliers');
			$this->db->like('company_name', $search);
			// restrict to non deleted companies only if is_deleted is FALSE
			$this->db->where('deleted', $filters['is_deleted']);
			$this->db->distinct();
			$this->db->order_by('company_name', 'asc');
			foreach($this->db->get()->result() as $row)
			{
				$suggestions[] = array('label' => $row->company_name);
			}

			//Search by description
			$this->db->select('item_id, name, description');
			$this->db->from('items');
			$this->db->where('deleted', $filters['is_deleted']);
			$this->db->like('description', $search);
			$this->db->order_by('description', 'asc');
			foreach($this->db->get()->result() as $row)
			{
				$entry = array('value' => $row->item_id, 'label' => $row->name);
				if(!array_walk($suggestions, function($value, $label) use ($entry) { return $entry['label'] != $label; } ))
				{
					$suggestions[] = $entry;
				}
			}

			//Search by custom fields
			if($filters['search_custom'] != FALSE)
			{
				$this->db->from('items');
				$this->db->group_start();
					$this->db->like('custom1', $search);
					$this->db->or_like('custom2', $search);
					$this->db->or_like('custom3', $search);
					$this->db->or_like('custom4', $search);
					$this->db->or_like('custom5', $search);
					$this->db->or_like('custom6', $search);
					$this->db->or_like('custom7', $search);
					$this->db->or_like('custom8', $search);
					$this->db->or_like('custom9', $search);
					$this->db->or_like('custom10', $search);
				$this->db->group_end();
				$this->db->where('deleted', $filters['is_deleted']);
				foreach($this->db->get()->result() as $row)
				{
					$suggestions[] = array('value' => $row->item_id, 'label' => $row->name);
				}
			}
		}

		//only return $limit suggestions
		if(count($suggestions > $limit))
		{
			$suggestions = array_slice($suggestions, 0,$limit);
		}

		return $suggestions;
	}

	public function get_category_suggestions($search)
	{
		$suggestions = array();
		$this->db->distinct();
		$this->db->select('category');
		$this->db->from('items');
		$this->db->like('category', $search);
		$this->db->where('deleted', 0);
		$this->db->order_by('category', 'asc');
		foreach($this->db->get()->result() as $row)
		{
			$suggestions[] = array('label' => $row->category);
		}

		return $suggestions;
	}
	
	public function get_location_suggestions($search)
	{
		$suggestions = array();
		$this->db->distinct();
		$this->db->select('location');
		$this->db->from('items');
		$this->db->like('location', $search);
		$this->db->where('deleted', 0);
		$this->db->order_by('location', 'asc');
		foreach($this->db->get()->result() as $row)
		{
			$suggestions[] = array('label' => $row->location);
		}
	
		return $suggestions;
	}

	public function get_custom_suggestions($search, $field_no)
	{
		$suggestions = array();
		$this->db->distinct();
		$this->db->select('custom'.$field_no);
		$this->db->from('items');
		$this->db->like('custom'.$field_no, $search);
		$this->db->where('deleted', 0);
		$this->db->order_by('custom'.$field_no, 'asc');
		foreach($this->db->get()->result() as $row)
		{
			$row_array = (array) $row;
			$suggestions[] = array('label' => $row_array['custom'.$field_no]);
		}
	
		return $suggestions;
	}

	public function get_categories()
	{
		$this->db->select('category');
		$this->db->from('items');
		$this->db->where('deleted', 0);
		$this->db->distinct();
		$this->db->order_by('category', 'asc');

		return $this->db->get();
	}

	/*
	 * changes the cost price of a given item
	 * calculates the average price between received items and items on stock
	 * $item_id : the item which price should be changed
	 * $items_received : the amount of new items received
	 * $new_price : the cost-price for the newly received items
	 * $old_price (optional) : the current-cost-price
	 *
	 * used in receiving-process to update cost-price if changed
	 * caution: must be used before item_quantities gets updated, otherwise the average price is wrong!
	 *
	 */
	public function change_cost_price($item_id, $items_received, $new_price, $old_price = null)
	{
		if($old_price === null)
		{
			$item_info = $this->get_info($item_id);
			$old_price = $item_info->cost_price;
		}

		$this->db->from('item_quantities');
		$this->db->select_sum('quantity');
		$this->db->where('item_id', $item_id);
		$this->db->join('stock_locations', 'stock_locations.location_id=item_quantities.location_id');
		$this->db->where('stock_locations.deleted', 0);
		$old_total_quantity = $this->db->get()->row()->quantity;

		$total_quantity = $old_total_quantity + $items_received;
		$average_price = bcdiv(bcadd(bcmul($items_received, $new_price), bcmul($old_total_quantity, $old_price)), $total_quantity);

		$data = array('cost_price' => $average_price);

		return $this->save($data, $item_id);
	}

	//Mi funcion para calcular precio segun lista de precios por cantidad
	public function price_calc($item_id, $quantity)
	{
		/*
		SELECT item_unit_price 
		FROM ospos_prices,
		ospos_price_list,
		ospos_prices_items
		WHERE ospos_prices.price_id=ospos_price_list.price_id
		and ospos_prices.price_id=ospos_prices_items.price_id
		and ospos_prices_items.item_id=1
		and ospos_price_list.quantity_purchased<=13
		order by ospos_price_list.quantity_purchased desc
		limit 1
		*/
		//echo $item_id." x ".$quantity;
		//die();

		$this->db->select('ospos_price_list.item_unit_price');
		$this->db->from('ospos_price_list');
		$this->db->join('ospos_prices_items', 'ospos_prices_items.price_id=ospos_price_list.price_id');
		$this->db->where('ospos_prices_items.item_id', $item_id);
		$this->db->where('ospos_price_list.quantity_purchased <=',$quantity);
		$this->db->order_by('ospos_price_list.quantity_purchased', 'desc');
		$this->db->limit(1);
		

		/*$this->db->select('ospos_price_list.item_unit_price');
		$this->db->from('ospos_price_list');
		$this->db->where('ospos_price_list.price_id', 1);
		$this->db->limit(1);*/
		//$price_temp = $this->db->get()->row()->item_unit_price;
		//echo "precio ". $price_temp;
		//die();
		return $this->db->get()->row()->item_unit_price;
		//return 3300;
	}

	/*
	Mi funcion para retornar todas las listas de precios
	*/
	public function get_all_prices()
	{
		$this->db->from('ospos_prices');
		return $this->db->get();
	}

	/*
	Mi funcion para retornar todas los precios de una lista de precios
	*/
	public function get_price_list($price_id)
	{
		$this->db->from('ospos_price_list');
		$this->db->where('ospos_price_list.price_id',$price_id);
		return $this->db->get();
	}

	/*
	Mi funcion para retornar todas los items/articulos de una lista de precios
	*/
	public function get_prices_items($price_id)
	{
		$this->db->select('ospos_prices_items.price_id');
		$this->db->select('ospos_prices_items.item_id');
		$this->db->select('ospos_items.item_number');
		$this->db->select('ospos_items.name');
		$this->db->select('ospos_items.custom2');
		$this->db->select('ospos_items.custom4');
		$this->db->from('ospos_prices_items');
		$this->db->join('ospos_items', 'ospos_prices_items.item_id=ospos_items.item_id');
		$this->db->where('ospos_prices_items.price_id',$price_id);
		return $this->db->get();
	}

	/*
	Mi funcion para retornar todas los items/articulos de una lista de precios
	*/
	public function get_price_id($item_id)
	{
		$this->db->select('ospos_prices_items.price_id');
		$this->db->from('ospos_prices_items');
		$this->db->where('ospos_prices_items.item_id',$item_id);
		$this->db->limit(1);
		
		return $this->db->get()->row()->price_id;
	}


	/*
	Mi funcion para retornar la descripcion de una lista de precios
	*/
	public function get_desc_price($price_id)
	{
		$this->db->select('ospos_prices.description');
		$this->db->from('ospos_prices');
		$this->db->where('ospos_prices.price_id',$price_id);
		$this->db->limit(1);

		return $this->db->get()->row()->description;
	}


	/*
	Mi funcion para retornar el impuesto del articulo
	*/
	public function get_item_taxes($item_id)
	{
		$this->db->select('ospos_items_taxes.percent');
		$this->db->from('ospos_items_taxes');
		$this->db->where('ospos_items_taxes.item_id',$item_id);
		$this->db->where('ospos_items_taxes.percent >',0);
		$this->db->limit(1);
		
		return $this->db->get()->row()->percent;
	}


	/*
	Mi funcion para retornar todas los precios de una lista de precios
	*/
	public function get_unit_prices($price_id)
	{
		$this->db->select('ospos_price_list.item_unit_price');
		$this->db->select('ospos_price_list.quantity_purchased');
		$this->db->select('ospos_price_list.pay_percent');
		$this->db->from('ospos_price_list');
		$this->db->where('ospos_price_list.price_id',$price_id);	
		return $this->db->get()->result_array();
	}

	public function get_category($item_id){
		//echo "ver granel";
		$this->db->select('ospos_items.category');
		$this->db->from('ospos_items');
		$this->db->where('ospos_items.item_number',$item_id);
		$this->db->limit(1);
		//echo $this->db->get()->row()->category;
		//die();
		return $this->db->get()->row()->category;

	}
	
	/*
	Mi funcion para retornar el costo promedio de una lista de precios
	*/
	public function get_costo_promedio($price_id)
	{
		$this->db->select_avg('ospos_items.cost_price');
		$this->db->from('ospos_items');
		$this->db->where('ospos_items.custom1',$price_id);

		return $this->db->get()->row()->cost_price;
	}

	/*
	Mi funcion para retornar el id
	*/
	public function get_id_item($item_number)
	{
		$this->db->select('ospos_items.item_id');
		$this->db->from('ospos_items');
		$this->db->where('ospos_items.item_number', $item_number);
		$this->db->limit(1);

		return $this->db->get()->row()->item_id;
	}

	public function get_item_number($item_id)
	{
		$this->db->select('ospos_items.item_number');
		$this->db->from('ospos_items');
		$this->db->where('ospos_items.item_id', $item_id);
		$this->db->limit(1);

		return $this->db->get()->row()->item_number;
	}

	public function get_item_supplier($item_id)
	{
		$this->db->select('ospos_items.supplier_id');
		$this->db->from('ospos_items');
		$this->db->where('ospos_items.item_id', $item_id);
		$this->db->limit(1);

		return $this->db->get()->row()->supplier_id;
	}

	/*
	Gets information about a particular item by item id or number
	*/
	public function get_info_by_id_or_number_custom($item_id)
	{
		$this->db->from('items');

        //if (ctype_digit($item_id))
        //{
            $this->db->group_start();

                //$this->db->where('items.item_number', $item_id);
                //Solo debe buscar por codigo de barras o sea item_number
                $this->db->where('item_id', (int) $item_id);
                //$this->db->or_where('items.item_number', $item_id);
            $this->db->group_end();
        //}
        //else
        //{
        //    $this->db->where('item_number', $item_id);
        //}

		$this->db->where('items.deleted', 0);

		$query = $this->db->get();

		if($query->num_rows() == 1)
		{
			return $query->row();
		}

		return '';
	}

	/* Get lista de precios por proveedor*/
	public function get_supplier_price_list($supplier_id)
	{
		$sql="select ospos_items.item_number,ospos_items.name, 
			(select item_unit_price
			 from ospos_prices_items,ospos_price_list
			 where ospos_prices_items.price_id=ospos_price_list.price_id
			and ospos_items.item_id=ospos_prices_items.item_id
			 and ospos_price_list.quantity_purchased=0
			 limit 1
			) as minorista,
			(select item_unit_price*quantity_purchased
			 from ospos_prices_items,ospos_price_list
			 where ospos_prices_items.price_id=ospos_price_list.price_id
			and ospos_items.item_id=ospos_prices_items.item_id
			 and ospos_price_list.quantity_purchased>0
			 and ospos_price_list.quantity_purchased<ospos_items.custom2
			) as mayorista1,
			(select item_unit_price*quantity_purchased
			 from ospos_prices_items,ospos_price_list
			 where ospos_prices_items.price_id=ospos_price_list.price_id
			and ospos_items.item_id=ospos_prices_items.item_id
			 and ospos_price_list.quantity_purchased=ospos_items.custom2
			 limit 1
			) as mayorista2,
			(select item_unit_price*quantity_purchased
			 from ospos_prices_items,ospos_price_list
			 where ospos_prices_items.price_id=ospos_price_list.price_id
			and ospos_items.item_id=ospos_prices_items.item_id
			 and ospos_price_list.quantity_purchased>ospos_items.custom2
			 and ospos_items.custom2<>ospos_items.custom4
			 limit 1
			) as mayorista3
			from ospos_items
			where ospos_items.supplier_id=?
			order by ospos_items.name";		

		$query=$this->db->query($sql,array($supplier_id));
		$r=$query->result();
		return $r;
	}

	/* Get lista de precios por categoria*/
	public function get_category_price_list($category)
	{
		$sql="select ospos_items.item_number,ospos_items.name, ospos_items.custom2,
			(select item_unit_price
			 from ospos_prices_items,ospos_price_list
			 where ospos_prices_items.price_id=ospos_price_list.price_id
			and ospos_items.item_id=ospos_prices_items.item_id
			 and ospos_price_list.quantity_purchased=0
			 limit 1
			) as minorista,
			(select item_unit_price*quantity_purchased
			 from ospos_prices_items,ospos_price_list
			 where ospos_prices_items.price_id=ospos_price_list.price_id
			and ospos_items.item_id=ospos_prices_items.item_id
			 and ospos_price_list.quantity_purchased>0
			 and ospos_price_list.quantity_purchased<ospos_items.custom2
			) as mayorista1,
			(select item_unit_price*quantity_purchased
			 from ospos_prices_items,ospos_price_list
			 where ospos_prices_items.price_id=ospos_price_list.price_id
			and ospos_items.item_id=ospos_prices_items.item_id
			 and ospos_price_list.quantity_purchased=ospos_items.custom2
			 limit 1
			) as mayorista2,
			(select item_unit_price*quantity_purchased
			 from ospos_prices_items,ospos_price_list
			 where ospos_prices_items.price_id=ospos_price_list.price_id
			and ospos_items.item_id=ospos_prices_items.item_id
			 and ospos_price_list.quantity_purchased>ospos_items.custom2
			 and ospos_items.custom2<>ospos_items.custom4
			 limit 1
			) as mayorista3
			from ospos_items
			where ospos_items.category=?
			order by ospos_items.name
			limit 60";		

		$query=$this->db->query($sql,array($category));
		$r=$query->result();
		return $r;
	}

	public function get_max_price($price_id)
	{
		$this->db->select_max('ospos_price_list.item_unit_price');
		$this->db->from('ospos_price_list');
		$this->db->where('ospos_price_list.price_id', $price_id);
		$this->db->limit(1);

		return $this->db->get()->row()->item_unit_price;
	}

	/* Get lista de items por */
	public function get_receiving_stock($fecha_ini,$fecha_fin)
	{
		$sql="select date(r.receiving_time) receiving_time,r.receiving_id,i.item_number,i.name,ri.quantity_purchased,r.comment,q.quantity
			from ospos_receivings r,ospos_receivings_items ri,ospos_items i,ospos_item_quantities q
			where r.receiving_id=ri.receiving_id
			and ri.item_id=i.item_id
			and ri.item_id=q.item_id
			and ri.item_location=q.location_id
			and date(r.receiving_time) between date(?) and date(?)";		

		$query=$this->db->query($sql,array($fecha_ini,$fecha_fin));
		$r=$query->result();
		return $r;
	}

	public function get_vencimientos($fecha_ini,$fecha_fin)
	{
		$sql="select date(r.receiving_time) receiving_time,date(ri.expiry_date) expiry_date,r.receiving_id,i.item_number,i.name,sum(ri.quantity_purchased) quantity_purchased,q.quantity
			from ospos_receivings r,ospos_receivings_items ri,ospos_items i,ospos_item_quantities q
			where r.receiving_id=ri.receiving_id
			and ri.item_id=i.item_id
			and ri.item_id=q.item_id
			and ri.item_location=q.location_id
			and date(ri.expiry_date) between date(?) and date(?)
			group by date(ri.expiry_date)";		

		$query=$this->db->query($sql,array($fecha_ini,$fecha_fin));
		$r=$query->result();
		return $r;
	}

	/* Get lista de detalle de ventas */
	public function get_pos_items()
	{
		$sql="select ospos_items_pos.pos_id,ospos_items_pos.item_id,ospos_items_pos.item_number,ospos_items_pos.item_name,ospos_items_pos.button_type,ospos_items_pos.button_size,ospos_items_pos.category
		from ospos_items_pos
		
        order by ospos_items_pos.pos_id";		

		$query=$this->db->query($sql);
		$r=$query->result();
		return $r;
	}

	public function get_pos_list()
	{
		$this->db->from('ospos_items_pos');
		return $this->db->get();
	}

	public function get_max_pos_id()
	{
		$this->db->select_max('ospos_items_pos.pos_id');
		$this->db->from('ospos_items_pos');
		$this->db->limit(1);

		return $this->db->get()->row()->pos_id;
	}

	public function get_pos_categories()
	{
		$sql="select distinct ospos_items.category
		from ospos_items
		where ospos_items.deleted=0
		and ospos_items.category <> 'MATERIAS PRIMAS'
		and ospos_items.category <> 'GASTOS'";		

		$query=$this->db->query($sql);
		$r=$query->result();
		return $r;
	}

	public function get_pos_items_category($category)
	{
		$sql="select ospos_items.item_id,ospos_items.name,ospos_items.item_number,ospos_items.pic_id,ospos_items.unit_price
		from ospos_items
		where ospos_items.category = ? 
		and ospos_items.deleted=0";		

		$query=$this->db->query($sql,$category);
		$r=$query->result();
		return $r;
	}

	/*Formulas*/
	public function get_formulas()
	{	
		$this->db->select('ospos_formulas.formula_id');
		$this->db->select('ospos_formulas.description');
		$this->db->select('ospos_formulas.item_id');
		$this->db->select('ospos_formulas.quantity');
		$this->db->select('ospos_formulas.unit_measurement');
		$this->db->select('ospos_items.name');
		$this->db->select('ospos_items.item_number');
		$this->db->from('ospos_formulas');
		$this->db->join('ospos_items', 'ospos_formulas.item_id=ospos_items.item_id');
		$this->db->order_by('ospos_formulas.formula_id', 'DESC');
		return $this->db->get();
	}

	public function get_formulas_items($formula_id)
	{	
		$this->db->select('ospos_formulas_items.formula_id');
		$this->db->select('ospos_formulas_items.item_id');
		$this->db->select('ospos_formulas_items.quantity');
		$this->db->select('ospos_formulas_items.unit_measurement');
		$this->db->select('ospos_items.name');
		$this->db->select('ospos_items.item_number');
		$this->db->select('ospos_items.cost_price');
		$this->db->from('ospos_formulas_items');
		$this->db->join('ospos_items', 'ospos_formulas_items.item_id=ospos_items.item_id');
		$this->db->where('ospos_formulas_items.formula_id',$formula_id);
		return $this->db->get();
	}

	public function get_formulas_row($formula_id)
	{	
		$this->db->select('ospos_formulas.formula_id');
		$this->db->select('ospos_formulas.item_id');
		$this->db->select('ospos_formulas.quantity');
		$this->db->select('ospos_formulas.unit_measurement');
		$this->db->select('ospos_formulas.description');
		$this->db->select('ospos_items.name');
		$this->db->select('ospos_items.item_number');
		$this->db->from('ospos_formulas');
		$this->db->join('ospos_items', 'ospos_formulas.item_id=ospos_items.item_id');
		$this->db->where('ospos_formulas.formula_id',$formula_id);
		$this->db->limit(1);
		return $this->db->get();
	}

	/*Fin Fórmulas*/

	public function get_pos_items_order()
	{
		$sql="select ospos_items.item_id,ospos_items.name,ospos_items.item_number,ospos_items.pic_id,ospos_items.unit_price
		from ospos_items
		where ospos_items.category <> 'MATERIAS PRIMAS' 
		and ospos_items.deleted=0
		order by ospos_items.category";		

		$query=$this->db->query($sql);
		$r=$query->result();
		return $r;
	}

	public function get_location_name($location_id)
	{
		$this->db->select('ospos_stock_locations.location_name');
		$this->db->from('ospos_stock_locations');
		$this->db->where('ospos_stock_locations.location_id', $location_id);
		$this->db->limit(1);

		return $this->db->get()->row()->location_name;
	}

	public function get_stock_item_loc($item_id,$location_id)
	{
		$this->db->select('ospos_item_quantities.quantity');
		$this->db->from('ospos_item_quantities');
		$this->db->where('ospos_item_quantities.item_id', $item_id);
		$this->db->where('ospos_item_quantities.location_id',$location_id);
		$this->db->limit(1);

		return $this->db->get()->row()->quantity;
	}

	public function get_pack_items($item_id)
	{
		$sql="select pi.item_id,
		    pi.item_id_item,
		    pi.quantity,
		    pi.unit_price,
		    pi.cost_price,
            i.item_number,
            i.name
		from ospos_item_pack_items pi, ospos_items i
		where pi.item_id=?
		and i.item_id=pi.item_id_item";		
		//echo "in 1 ";
		$query=$this->db->query($sql,array($item_id));
		//echo "in 2 ";
		$r=$query->result();
		//echo "in 3 ";
		return $r;
	}

	public function get_inventory_stock_date($location_id,$fecha_ini,$fecha_fin)
	{
		$sql="select i.item_id,i.name,i.item_number,i.category, sum(m.trans_inventory) trans_inventory
			from ospos_items i, ospos_inventory m
			where i.item_id=m.trans_items
			and m.trans_location=?
			and date(m.trans_date) between ? and ?
			group by i.item_id";		
		//echo "in 1 ";
		$query=$this->db->query($sql,array($location_id,$fecha_ini,$fecha_fin));
		//echo "in 2 ";
		$r=$query->result();
		//echo "in 3 ";
		return $r;
	}

	public function get_max_id()
	{
		$this->db->select_max('ospos_items.item_id');
		$this->db->from('ospos_items');
		$this->db->limit(1);

		return $this->db->get()->row()->item_id;
	}

	public function get_mesas()
	{	
		//echo "string";
		$query = $this->db->query("select c.value val
					from ospos_app_config c
					where c.key = 'mesas' limit 1");
		$return = 0;
		foreach ($query->result_array() as $row) {
			$return = $row['val'];
		}

		return $return;
	}

	public function get_category_list()
	{
		$uno=1;
		$sql="SELECT distinct(category) category
			FROM ospos_items
			where deleted=0
			order by 1";

		$query=$this->db->query($sql,array());
		$r=$query->result();
		return $r;
	}
}
?>


